
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2018-05-20T09:40:34-0500",
 "dirty": false,
 "error": null,
 "full-revisionid": "ba62b3dde8dd62f41c2b6c53001e6de501cc58f5",
 "version": "3.10.4"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
